import UIKit

class LevelGauge: UIView {

    var labelText: String = "Foo" {
        didSet {
            updateDisplay()
        }
    }

    var value: Int = 0 {
        didSet {
            updateDisplay()
        }
    }

    private let label = UILabel()

    private let colors = [
        UIColor(red: 0.617, green: 0.571, blue: 0.383, alpha: 1),
        UIColor(red: 0.679, green: 0.644, blue: 0.362, alpha: 1),
        UIColor(red: 0.739, green: 0.720, blue: 0.337, alpha: 1),
        UIColor(red: 0.898, green: 0.910, blue: 0.745, alpha: 1),
        UIColor(red: 0.855, green: 0.909, blue: 0.674, alpha: 1),
    ]

    override func awakeFromNib() {
        super.awakeFromNib()

        let cornerRadius: CGFloat = 2

        backgroundColor = UIColor.white
        layer.cornerRadius = cornerRadius
        layer.masksToBounds = true

        let height = bounds.size.height - 2 * cornerRadius
        let width = cornerRadius + CGFloat(colors.count) * (height + cornerRadius)

        for i in 0..<colors.count {
            let segment = UIView(frame: CGRect(x: cornerRadius + CGFloat(i) * (height + cornerRadius), y: cornerRadius, width: height, height: height))
            segment.layer.cornerRadius = cornerRadius
            segment.tag = 100 + i
            addSubview(segment)
        }

        label.frame = CGRect(x: width, y: cornerRadius, width: bounds.size.width - width - cornerRadius, height: height)
        label.backgroundColor = UIColor(red: 0.936, green: 0.936, blue: 0.936, alpha:1)
        label.layer.cornerRadius = cornerRadius
        label.font = UIFont.boldSystemFont(ofSize: 11)
        label.textAlignment = .center
        label.textColor = UIColor.black
        label.text = labelText
        addSubview(label)
    }

    private func updateDisplay() {
        for i in 0..<colors.count {
            let segment = viewWithTag(100 + i)
            if value >= i + 1 {
                segment?.backgroundColor = colors[i]
            } else {
                segment?.backgroundColor = UIColor.white
            }
        }

        label.text = labelText
    }

}
